camelot.camelot.view.proxy.collection_proxy

Package camelot :: Package camelot :: Package view :: Package proxy :: Module collection_proxy |
[hide private]
[frames] | no frames]

# Module collection_proxy

source code

Proxy representing a collection of entities that live in the model thread.

The proxy represents them in the gui thread and provides access to the data with zero delay. If the data is not yet present in the proxy, dummy data is returned and an update signal is emitted when the correct data is available.

Classes | [hide private]
| DelayedProxy A proxy object needs to be constructed within the GUI thread.
| EmptyRowData
| CollectionProxy The CollectionProxy contains a limited copy of the data in the actual collection, usable for fast visualisation in a QTableView

Functions | [hide private]
RowDataFromObject(obj, columns) Create row data from an object, by fetching its attributes | source code
RowDataAsUnicode(row_data) | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.proxy.collection_proxy')`
| verbose = `False`
| empty_row_data = `EmptyRowData()`

Function Details | [hide private]

### RowDataFromObject(obj, columns) | source code
Create row data from an object, by fetching its attributes Decorators: `@model_function`